@@ -4,11 +4,11 @@ use strict;
 use warnings;
 
 use Text::CSV;
-use IO::Handle;
+use IO::File;
 
 use vars qw/$VERSION/;
 
-$VERSION = 0.8;
+$VERSION = 1.0;
 
 sub new {
   my $class = shift;
@@ -32,7 +32,7 @@ sub load {
     return _from_handle($io,\%opt);
   }
   elsif (defined $opt{file}) {
-    my $io = new IO::Handle;
+    my $io = new IO::File;
     open($io, "<$opt{file}") || die "Could not open $opt{file} $!";
     delete $opt{file};
     return _from_handle($io,\%opt);
@@ -139,7 +139,7 @@ I often need to take a CSV file that has a header row and turn it into
 a perl data structure for further manipulation. This package does that
 in as few steps as possible.
 
-I've added a C<create> method in version 0.8 because sometimes you just
+I added a C<create> method in version 0.8 because sometimes you just
 want to create some bog standard CSV from an array of hashes.
 
 =head1 USAGE
@@ -169,7 +169,7 @@ Instantiate an object.
   my $data = Text::CSV::Slurp->load(file => $filename);
   my $data = $slurp->load(file => $filename);
 
-Returns an array of hashes. Any extra arguments are passed to L<Text::CSV>.
+Returns an arrayref of hashrefs. Any extra arguments are passed to L<Text::CSV>.
 The first line of the CSV is assumed to be a header row. Its fields are
 used as the keys for each of the hashes.
 
@@ -184,21 +184,20 @@ used as the keys for each of the hashes.
  print FH $csv;
  close FH;
 
-Creates CSV from an array of hashes and returns it as a string. All optional
+Creates CSV from an arrayref of hashrefs and returns it as a string. All optional
 arguments are passed to L<Text::CSV> except for C<field_order>, which is used
 to determine the fields and order in which they appear in the CSV. For example:
 
  my $csv = Text::CSV::Slurp->create( input => \@array_of_hashes, field_order => ['one','three','two'] );
 
-If field_order is not supplied then the sorted keys of the first hash in the 
+If field_order is not supplied then the sorted keys of the first hash in the
 input are used instead.
 
-
 =head1 DEPENDENCIES
 
 L<Text::CSV>
 
-L<IO::Handle>
+L<IO::File>
 
 L<Test::Most> - for tests only
 
